<!DOCTYPE html>
<html>
  <head>
    <meta name="viewport" content="initial-scale=1.0, user-scalable=no">
    <meta charset="utf-8">
    <title>County Overlay</title>
    <link rel="stylesheet" href="CQX_StyleSheet-new.css" type="text/css" />

    <style>
      html, body, #map-canvas {
        height: 100%;
        margin: 0px;
        padding: 0px
      }
      html, body, #countySelection{width: 100%; height: 100%}
    </style>


    <script src="https://maps.googleapis.com/maps/api/js?v=3.exp"></script>

    <script language="javascript" type="text/javascript">

    var map;
    var infoWindow;
    var theCountyMarkers = new Array();
    var theCountyValues = new Array();
    var cqxUrl = "http://www.no5w.com";


    var stateFullName = "South Dakota";
    var qsoPartyUrl = "http://www.kb0wsw.com/SDQP/";
    var overlayUrl = "http://www.no5w.com/OverlaySouthDakotaRev04.kml";

    /*-----------------------------------------------------------------------------------------------------
     PromoControl: constructor for the QSO Party promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function PromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access QSO Party home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '24px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String(stateFullName) + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(qsoPartyUrl));
      });
    }//PromoControl constructor

    /*-----------------------------------------------------------------------------------------------------
     CQXPromoControl: constructor for the CQ/X promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function CQXPromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access CQ/X home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '12px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String("CQ/X de NO5W") + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(cqxUrl));
      });
    }//CQXPromoControl constructor

/*-----------------------------------------------------------------------------------------------------
 addMarker: function for adding a county marker
-----------------------------------------------------------------------------------------------------*/
function addMarker(lat, lon, desc, aval) {
  var markerLatLng = new google.maps.LatLng(lat, lon);

  var markerOptions = {
    flat: true,
    map: map,
    optimized: false,
    position: markerLatLng,
    visible: true,
    title: desc
    };
  var marker = new google.maps.Marker(markerOptions);
  theCountyMarkers.push(marker);
  theCountyValues.push(aval);

  }//addMarker

/*-----------------------------------------------------------------------------------------------------
 removeMarkers: function for removing all of the current markers
 -----------------------------------------------------------------------------------------------------*/
function removeMarkers() {
  for(var i=0;i<theCountyMarkers.length;i++) theCountyMarkers[i].setMap(null);
  }//removeMarkers     

/*-----------------------------------------------------------------------------------------------------
 populateCountySelection: function for building the county selection
 -----------------------------------------------------------------------------------------------------*/
function populateCountySelection() {
  var countySelection = document.getElementById("countySelection");
          
  countySelection.options.length = 0;
  theCountyMarkers.length = 0;
  theCountyValues.length = 0;

  countySelection.options[0] = new Option("Aurora", "auro");
  countySelection.options[1] = new Option("Beadle", "bead");
  countySelection.options[2] = new Option("Bennett", "benn");
  countySelection.options[3] = new Option("BonHomme", "bonh");
  countySelection.options[4] = new Option("Brookings", "broo");
  countySelection.options[5] = new Option("Brown", "brwn");
  countySelection.options[6] = new Option("Brule", "brul");
  countySelection.options[7] = new Option("Buffalo", "buff");
  countySelection.options[8] = new Option("Butte", "butt");
  countySelection.options[9] = new Option("Campbell", "camp");
  countySelection.options[10] = new Option("CharlesMix", "char");
  countySelection.options[11] = new Option("Clark", "clrk");
  countySelection.options[12] = new Option("Clay", "clay");
  countySelection.options[13] = new Option("Codington", "codi");
  countySelection.options[14] = new Option("Corson", "cors");
  countySelection.options[15] = new Option("Custer", "cust");
  countySelection.options[16] = new Option("Davison", "davi");
  countySelection.options[17] = new Option("Day", "day");
  countySelection.options[18] = new Option("Deuel", "deue");
  countySelection.options[19] = new Option("Dewey", "dewy");
  countySelection.options[20] = new Option("Douglas", "dgls");
  countySelection.options[21] = new Option("Edmunds", "edmu");
  countySelection.options[22] = new Option("FallRiver", "fall");
  countySelection.options[23] = new Option("Faulk", "faul");
  countySelection.options[24] = new Option("Grant", "gran");
  countySelection.options[25] = new Option("Gregory", "greg");
  countySelection.options[26] = new Option("Haakon", "haak");
  countySelection.options[27] = new Option("Hamlin", "haml");
  countySelection.options[28] = new Option("Hand", "hand");
  countySelection.options[29] = new Option("Hanson", "hnsn");
  countySelection.options[30] = new Option("Harding", "hrdg");
  countySelection.options[31] = new Option("Hughes", "hugh");
  countySelection.options[32] = new Option("Hutchinson", "hutc");
  countySelection.options[33] = new Option("Hyde", "hyde");
  countySelection.options[34] = new Option("Jackson", "jksn");
  countySelection.options[35] = new Option("Jerauld", "jera");
  countySelection.options[36] = new Option("Jones", "jone");
  countySelection.options[37] = new Option("Kingsbury", "king");
  countySelection.options[38] = new Option("Lake", "lake");
  countySelection.options[39] = new Option("Lawrence", "lawr");
  countySelection.options[40] = new Option("Lincoln", "linc");
  countySelection.options[41] = new Option("Lyman", "lyma");
  countySelection.options[42] = new Option("Marshall", "mrsh");
  countySelection.options[43] = new Option("McCook", "mcoo");
  countySelection.options[44] = new Option("McPherson", "mcph");
  countySelection.options[45] = new Option("Meade", "mead");
  countySelection.options[46] = new Option("Mellette", "mell");
  countySelection.options[47] = new Option("Miner", "mine");
  countySelection.options[48] = new Option("Minnehaha", "minn");
  countySelection.options[49] = new Option("Moody", "mood");
  countySelection.options[50] = new Option("Pennington", "penn");
  countySelection.options[51] = new Option("Perkins", "perk");
  countySelection.options[52] = new Option("Potter", "pott");
  countySelection.options[53] = new Option("Roberts", "robe");
  countySelection.options[54] = new Option("Sanborn", "sanb");
  countySelection.options[55] = new Option("Shannon", "shan");
  countySelection.options[56] = new Option("Spink", "spin");
  countySelection.options[57] = new Option("Stanley", "stan");
  countySelection.options[58] = new Option("Sully", "sull");
  countySelection.options[59] = new Option("Todd", "todd");
  countySelection.options[60] = new Option("Tripp", "trip");
  countySelection.options[61] = new Option("Turner", "turn");
  countySelection.options[62] = new Option("Union", "unio");
  countySelection.options[63] = new Option("Walworth", "walw");
  countySelection.options[64] = new Option("Yankton", "yank");
  countySelection.options[65] = new Option("Ziebach", "zieb");
  addMarker(43.71830000, -98.56410000, "Aurora", "auro");
  addMarker(44.41430000, -98.27950000, "Beadle", "bead");
  addMarker(43.19320000, -101.66900000, "Bennett", "benn");
  addMarker(42.96600000, -97.89900000, "BonHomme", "bonh");
  addMarker(44.36970000, -96.79070000, "Brookings", "broo");
  addMarker(45.58950000, -98.35210000, "Brown", "brwn");
  addMarker(43.71720000, -99.13180000, "Brule", "brul");
  addMarker(44.06490000, -99.25150000, "Buffalo", "buff");
  addMarker(44.89220000, -103.50800000, "Butte", "butt");
  addMarker(45.76840000, -100.10800000, "Campbell", "camp");
  addMarker(43.16840000, -98.69000000, "CharlesMix", "char");
  addMarker(44.84860000, -97.73720000, "Clark", "clrk");
  addMarker(42.89390000, -96.98310000, "Clay", "clay");
  addMarker(44.97760000, -97.18850000, "Codington", "codi");
  addMarker(45.70840000, -101.15500000, "Corson", "cors");
  addMarker(43.66670000, -103.37100000, "Custer", "cust");
  addMarker(43.67490000, -98.14540000, "Davison", "davi");
  addMarker(45.36990000, -97.60400000, "Day", "day");
  addMarker(44.76050000, -96.66840000, "Deuel", "deue");
  addMarker(45.09860000, -100.87900000, "Dewey", "dewy");
  addMarker(43.34840000, -98.40850000, "Douglas", "dgls");
  addMarker(45.41860000, -99.21570000, "Edmunds", "edmu");
  addMarker(43.23960000, -103.52800000, "FallRiver", "fall");
  addMarker(45.07120000, -99.14520000, "Faulk", "faul");
  addMarker(45.15150000, -96.83930000, "Grant", "gran");
  addMarker(43.24880000, -99.01640000, "Gregory", "greg");
  addMarker(44.37070000, -101.52700000, "Haakon", "haak");
  addMarker(44.67370000, -97.18830000, "Hamlin", "haml");
  addMarker(44.54600000, -99.00670000, "Hand", "hand");
  addMarker(43.67500000, -97.78740000, "Hanson", "hnsn");
  addMarker(45.57890000, -103.49400000, "Harding", "hrdg");
  addMarker(44.32310000, -100.09000000, "Hughes", "hugh");
  addMarker(43.33400000, -97.75690000, "Hutchinson", "hutc");
  addMarker(44.54510000, -99.48820000, "Hyde", "hyde");
  addMarker(43.69200000, -101.60200000, "Jackson", "jksn");
  addMarker(44.06600000, -98.62940000, "Jerauld", "jera");
  addMarker(43.93870000, -100.70200000, "Jones", "jone");
  addMarker(44.36960000, -97.49090000, "Kingsbury", "king");
  addMarker(44.02190000, -97.12950000, "Lake", "lake");
  addMarker(44.37270000, -103.75400000, "Lawrence", "lawr");
  addMarker(43.29190000, -96.68080000, "Lincoln", "linc");
  addMarker(43.85860000, -99.82430000, "Lyman", "lyma");
  addMarker(45.74700000, -97.60330000, "Marshall", "mrsh");
  addMarker(43.67430000, -97.36900000, "McCook", "mcoo");
  addMarker(45.76620000, -99.22140000, "McPherson", "mcph");
  addMarker(44.58980000, -102.78700000, "Meade", "mead");
  addMarker(43.62350000, -100.72100000, "Mellette", "mell");
  addMarker(44.02190000, -97.61040000, "Miner", "mine");
  addMarker(43.67460000, -96.79130000, "Minnehaha", "minn");
  addMarker(44.02220000, -96.67110000, "Moody", "mood");
  addMarker(44.09830000, -103.02800000, "Pennington", "penn");
  addMarker(45.49190000, -102.47900000, "Perkins", "perk");
  addMarker(45.07210000, -99.99840000, "Potter", "pott");
  addMarker(45.61640000, -96.84940000, "Roberts", "robe");
  addMarker(44.02330000, -98.09070000, "Sanborn", "sanb");
  addMarker(43.35270000, -102.54100000, "Shannon", "shan");
  addMarker(44.93770000, -98.34750000, "Spink", "spin");
  addMarker(44.47580000, -100.53000000, "Stanley", "stan");
  addMarker(44.72280000, -100.20200000, "Sully", "sull");
  addMarker(43.19410000, -100.71300000, "Todd", "todd");
  addMarker(43.38180000, -99.88230000, "Tripp", "trip");
  addMarker(43.29170000, -97.16280000, "Turner", "turn");
  addMarker(42.78160000, -96.62510000, "Union", "unio");
  addMarker(45.42030000, -100.09700000, "Walworth", "walw");
  addMarker(42.98490000, -97.39900000, "Yankton", "yank");
  addMarker(44.99200000, -101.56900000, "Ziebach", "zieb");

  countySelection.selectedIndex = 0;
  }

//----------------------------------------------------------------------------------------------------

function initialize() {

  populateCountySelection();

  var mapOptions = {
    zoom: 11
    };

  map = new google.maps.Map(document.getElementById('map-canvas'), mapOptions);

  var stateLayer = new google.maps.KmlLayer({url: overlayUrl, suppressInfoWindows: true});
  stateLayer.setMap(map);

  // Add a listener for the click event.
  google.maps.event.addListener(stateLayer, 'click', showLatLon);

  infoWindow = new google.maps.InfoWindow();

  var promoControlDiv = document.createElement('div');
  var promoControl = new PromoControl(promoControlDiv, map);

  promoControlDiv.index = 1;
  map.controls[google.maps.ControlPosition.TOP_CENTER].push(promoControlDiv);

  var promoCQXControlDiv = document.createElement('div');
  var promoCQXControl = new CQXPromoControl(promoCQXControlDiv, map);

  promoCQXControlDiv.index = 2;
  map.controls[google.maps.ControlPosition.TOP_RIGHT].push(promoCQXControlDiv);

  }

/*-----------------------------------------------------------------------------------------------------
 changeCounty: function processing a county change from the countySelection 
 -----------------------------------------------------------------------------------------------------*/
function changeCounty() {
  removeMarkers();
  var acounty = encodeURIComponent(document.getElementById("countySelection").value);
  var iMark = -1;
  for(i=0;i<theCountyValues.length;i++) {
    if(theCountyValues[i] != acounty) continue;
    iMark = i;
    break;
    }
  if(iMark < 0) return;
  map.setCenter(theCountyMarkers[iMark].getPosition());
  theCountyMarkers[iMark].setMap(map);
  }//function changeCounty

function catchEvent(eventObj, event, eventHandler) {
  if(eventObj.addEventListener) {
    eventObj.addEventListener(event, eventHandler, false);
    }
  else if(eventObj.attachEvent) {
    event = "on" + event;
    eventObj.attachEvent(event, eventHandler);
    }
  }//catchEvent

/*-----------------------------------------------------------------------------------------------------
 set up event handlers when the window loads 
 -----------------------------------------------------------------------------------------------------*/
catchEvent(window, "load", function() {
  document.getElementById("countySelection").onchange=changeCounty;
  });

function showLatLon(event) {

  var nameStr = event.featureData.name; //FullName=Abbrev Num
  var arrayOne = nameStr.split("=");
  var arrayTwo = arrayOne[1].split(" ");

  var contentString = '<b>Clicked on Location</b>' + '<br>' +
                    '<b>LatLon: </b>' + event.latLng.lat() + ',' + event.latLng.lng() + '<br>' +
                    '<b>In County: </b>' + arrayOne[0] + '(' + arrayTwo[0] + ')';

  // Replace the info window's content and position.
  infoWindow.setContent(contentString);
  infoWindow.setPosition(event.latLng);

  infoWindow.open(map);
  }

google.maps.event.addDomListener(window, 'load', initialize);


    </script>
  </head>

  <body>

    <table style="width: 1000px;">
      <tbody>
        <tr style="vertical-align: top;">

          <td>
          <form>
            <div class="elem" style = "width: 120px; height: 700px; margin: 0; padding: 0; overflow:auto;">
              <select id="countySelection" name="county" size='43'>
                <option> </option>
              </select>
            </div>
          </form>
          </td>

          <td>
            <div id="map-canvas" style="width: 880px; height: 700px;"></div>
          </td>
        </tr>
      </tbody>
    </table>

  </body>


</html>

